pub struct FullFile<'a> {
pub file_entry: FileEntry<'a>,
pub data: Vec<u8>,
pub address: u16,
pub length: u16,
}Expand description
A FileEntry with associated file data Should rename this.
Fields
file_entry: FileEntry<'a>The associated FileEntry for this file.
data: Vec<u8>The raw data for this file, not including metadata or structured information.
address: u16The address this file was at in memory .
length: u16The length of this file in bytes.