pub enum Format {
Unknown(u64),
DOS32(u64),
DOS33(u64),
ProDOS(u64),
}Expand description
The different types of Apple disks
Variants
Unknown(u64)
Unknown disk format. We may not have enough information at the current stage to know the format This is a simple data type so it should be fast to update
There’s a design decision here to use an Unknown enum variant as opposed to an Option with None. I don’t know if I made the right choice.
DOS32(u64)
Apple DOS (3.2)
DOS33(u64)
Apple DOS (3.3)
ProDOS(u64)
Apple ProDOS