pub enum ErrorKind {
Message(String),
Invalid(InvalidErrorKind),
Unimplemented(String),
NotFound(String),
IO(Error),
}Expand description
The kinds of errors that can occur when processing an image, ROM or other file.
Variants
Message(String)
Generic error type
Invalid(InvalidErrorKind)
An error that occurs when dealing with invalid or unexpected data.
Unimplemented(String)
The file was in a format that is unsupported or has unsupported features.
NotFound(String)
The data requested was not found in the image. This can occur when attempting to extract a specific file from a file, or when attempting to extract a certain sector or other item.
IO(Error)
An IO based error
Implementations