pub struct STXDiskHeader<'a> {
pub disk_id: &'a [u8],
pub version: u16,
pub tool_used: u16,
pub reserved_area_1: &'a [u8],
pub track_count: u8,
pub new_format: u8,
pub reserved_area_2: &'a [u8],
}Expand description
STXDiskHeader contains information about an Atari ST STX floppy disk image header 16 bytes
Fields
disk_id: &'a [u8]The disk identifier, “RSY\0”
version: u16The version of the disk image Usually version 3
tool_used: u16A 16-bit integer that indicates the tool used to create the image
reserved_area_1: &'a [u8]First reserved area, two reserved bytes
track_count: u8The number of tracks on the disk
new_format: u8Whether the disk is in the new format
reserved_area_2: &'a [u8]Second reserved area, four reserved bytes